chunk

Function chunk 

pub fn chunk(
    exchange_dataset: ExchangeDataset,
    protocol: &Protocols,
) -> Result<Chunked, String>
Group request-response pairs into protocol-aware chunks

If the protocol defines a required response length that is used, else actual response length used as fallback Returns an error if function code or length cannot be derived